==> bce-java-sdk-0.10.53-sources.jar: com/baidubce/services/bos/model/GetObjectAclRequest.java <==
/*
 * Copyright 2014 Baidu, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */
package com.baidubce.services.bos.model;

import com.baidubce.auth.BceCredentials;

public class GetObjectAclRequest extends GenericObjectRequest {

    /**
     * Constructs a void Constructor for GetObjectAclRequest.
     */
    public GetObjectAclRequest() {

    }

    /**
     * Constructs a new GetObjectAclRequest to get a specified object acl.
     * @param bucketName
     * @param key
     */
    public GetObjectAclRequest(String bucketName, String key) {
        super(bucketName, key);
    }

    @Override
    public GetObjectAclRequest withRequestCredentials(BceCredentials credentials) {
        this.setRequestCredentials(credentials);
        return this;
    }

    @Override
    public GetObjectAclRequest withBucketName(String bucketName) {
        this.setBucketName(bucketName);
        return this;
    }

    @Override
    public GetObjectAclRequest withKey(String key) {
        this.setKey(key);
        return this;
    }
}

==> bce-java-sdk-0.10.345-sources.jar: com/baidubce/services/bos/model/GetObjectAclRequest.java <==
/*
 * Copyright 2014 Baidu, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */
package com.baidubce.services.bos.model;

import com.baidubce.auth.BceCredentials;

public class GetObjectAclRequest extends GenericObjectRequest {

    /**
     * For versioning
     */
    private String versionId;


    /**
     * Constructs a void Constructor for GetObjectAclRequest.
     */
    public GetObjectAclRequest() {

    }

    /**
     * Constructs a new GetObjectAclRequest to get a specified object acl.
     * @param bucketName
     * @param key
     */
    public GetObjectAclRequest(String bucketName, String key) {
        super(bucketName, key);
    }

    @Override
    public GetObjectAclRequest withRequestCredentials(BceCredentials credentials) {
        this.setRequestCredentials(credentials);
        return this;
    }

    @Override
    public GetObjectAclRequest withBucketName(String bucketName) {
        this.setBucketName(bucketName);
        return this;
    }

    @Override
    public GetObjectAclRequest withKey(String key) {
        this.setKey(key);
        return this;
    }

    public String getVersionId() {
        return versionId;
    }

    public void setVersionId(String versionId) {
        this.versionId = versionId;
    }
}
